from django.utils.translation import ugettext_lazy as _
from fluent_contents.extensions import plugin_pool, ContentPlugin
from . import appsettings
from .models import CookieLawItem


@plugin_pool.register
class CookieLawPlugin(ContentPlugin):
    """
    Showing a cookie law notification
    """
    model = CookieLawItem
    category = _("Footer")
    render_template = "fluentcms_cookielaw/banner.html"

    class FrontendMedia:
        js = appsettings.FLUENTCMS_COOKIELAW_JS
        css = appsettings.FLUENTCMS_COOKIELAW_CSS



from django.test import TestCase
from fluent_contents.tests.factories import create_content_item
from fluent_contents.tests.utils import render_content_items
from fluentcms_cookielaw.models import CookieLawItem


class CookieLawTests(TestCase):
    """
    Testing private notes
    """

    def test_rendering(self):
        """
        Test the standard button
        """
        item = create_content_item(CookieLawItem, text="Do you like cookies?", button_text="Jummie!")
        output = render_content_items([item])

        self.assertHTMLEqual(output.html,
                             '''<div id="cookielaw-banner">
                                    <div class="container">
                                        <a class="btn" href="javascript:Cookielaw.accept();">Jummie!</a>
                                        Do you like cookies?
                                    </div>
                                </div>''')
        self.assertHTMLEqual(str(output.media), '<script type="text/javascript" src="/static/fluentcms_cookielaw/js/cookielaw.js"></script>')

        self.assertEqual(str(item), 'Do you like cookies?')



from django.conf import settings

_default_js = ('fluentcms_cookielaw/js/cookielaw.js',)

# Allow overriding the complete FrontendMedia definition
FLUENTCMS_COOKIELAW_JS = getattr(settings, 'FLUENTCMS_COOKIELAW_JS', _default_js)
FLUENTCMS_COOKIELAW_CSS = getattr(settings, 'FLUENTCMS_COOKIELAW_CSS', {})



from django.db import models
from django.utils.encoding import python_2_unicode_compatible
from django.utils.html import strip_tags
from django.utils.text import Truncator
from django.utils.translation import ugettext_lazy as _
from fluent_contents.extensions import PluginHtmlField
from fluent_contents.models import ContentItem


@python_2_unicode_compatible
class CookieLawItem(ContentItem):
    """
    Cookie law item
    """
    text = PluginHtmlField(_("Text"), help_text=_("For example: 'We use cookies to ensure you get the best experience on our website'"))
    button_text = models.CharField(_("Button text"), max_length=100)  # e.g. "Close" or "Accept"

    class Meta:
        verbose_name = _("Cookie notification")
        verbose_name_plural = _("Cookie notifications")

    def __str__(self):
        return Truncator(strip_tags(self.text)).words(20)
